# Smart link Local Python Package

## TODOs

TODO Create deeplink universal link for both mobile and web https://www.adjust.com/blog/universal-links-vs-deep-links/ <br>

Create QR Code for Smart link.<br>
